==> tuia-ecb-center-api-1.1.0.8-happy-20200401.020042-16-sources.jar: cn/com/duiba/tuia/ecb/center/happy/dto/HappyClearMediaConfigDTO.java <==
package cn.com.duiba.tuia.ecb.center.happy.dto;

import com.alibaba.fastjson.JSONObject;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

public class HappyClearMediaConfigDTO implements Serializable {

    private static final long serialVersionUID = 1642629521867719117L;

    private Long id;

    private Long appId;

    private JSONObject powerConfig;

    private Map<Integer, Integer> boxConfig;

    private Map<Integer, Integer> starBoxConfig;

    private List<HappyClearRewardDTO> happyClearRewardDto;

    private List<HappyClearExchangeItem> shoppingMallConfig;

    private Map<Integer, Integer> firstClearancePrizeConfig;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public JSONObject getPowerConfig() {
        return powerConfig;
    }

    public void setPowerConfig(JSONObject powerConfig) {
        this.powerConfig = powerConfig;
    }

    public Map<Integer, Integer> getBoxConfig() {
        return boxConfig;
    }

    public void setBoxConfig(Map<Integer, Integer> boxConfig) {
        this.boxConfig = boxConfig;
    }

    public List<HappyClearRewardDTO> getHappyClearRewardDto() {
        return happyClearRewardDto;
    }

    public void setHappyClearRewardDto(List<HappyClearRewardDTO> happyClearRewardDto) {
        this.happyClearRewardDto = happyClearRewardDto;
    }

    public Map<Integer, Integer> getStarBoxConfig() {
        return starBoxConfig;
    }

    public void setStarBoxConfig(Map<Integer, Integer> starBoxConfig) {
        this.starBoxConfig = starBoxConfig;
    }

    public List<HappyClearExchangeItem> getShoppingMallConfig() {
        return shoppingMallConfig;
    }

    public void setShoppingMallConfig(List<HappyClearExchangeItem> shoppingMallConfig) {
        this.shoppingMallConfig = shoppingMallConfig;
    }

    public Map<Integer, Integer> getFirstClearancePrizeConfig() {
        return firstClearancePrizeConfig;
    }

    public void setFirstClearancePrizeConfig(Map<Integer, Integer> firstClearancePrizeConfig) {
        this.firstClearancePrizeConfig = firstClearancePrizeConfig;
    }
}

==> tuia-ecb-center-api-1.1.0.29-happy-20200428.070531-15-sources.jar: cn/com/duiba/tuia/ecb/center/happy/dto/HappyClearMediaConfigDTO.java <==
package cn.com.duiba.tuia.ecb.center.happy.dto;

import com.alibaba.fastjson.JSONObject;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

public class HappyClearMediaConfigDTO implements Serializable {

    private static final long serialVersionUID = 1642629521867719117L;

    private Long id;

    private Long appId;

    //体力兑换配置
    private JSONObject powerConfig;

    //宝箱配置
    private Map<Integer, Integer> boxConfig;

    private List<HappyClearRewardDTO> happyClearRewardDto;

    private List<HappyClearExchangeItem> shoppingMallConfig;

    //一些额外配置
    private JSONObject extConfig;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public JSONObject getPowerConfig() {
        return powerConfig;
    }

    public void setPowerConfig(JSONObject powerConfig) {
        this.powerConfig = powerConfig;
    }

    public Map<Integer, Integer> getBoxConfig() {
        return boxConfig;
    }

    public void setBoxConfig(Map<Integer, Integer> boxConfig) {
        this.boxConfig = boxConfig;
    }

    public List<HappyClearRewardDTO> getHappyClearRewardDto() {
        return happyClearRewardDto;
    }

    public void setHappyClearRewardDto(List<HappyClearRewardDTO> happyClearRewardDto) {
        this.happyClearRewardDto = happyClearRewardDto;
    }

    public List<HappyClearExchangeItem> getShoppingMallConfig() {
        return shoppingMallConfig;
    }

    public void setShoppingMallConfig(List<HappyClearExchangeItem> shoppingMallConfig) {
        this.shoppingMallConfig = shoppingMallConfig;
    }

    public JSONObject getExtConfig() {
        return extConfig;
    }

    public void setExtConfig(JSONObject extConfig) {
        this.extConfig = extConfig;
    }
}
